@@ -9,7 +9,8 @@ from starlette import responses
 class VideosPage:
 
     def __init__(self) -> None:
-        with ui.page('/videos'):
+        @ui.page('/videos', 'Videos')
+        def page():
             self.list = ui.column()
             ui.timer(5, self.update_list)
 
