@@ -1,13 +1,19 @@
 import asyncio
 import logging
+import os
 import shlex
+import signal
 import subprocess
 import uuid
 from asyncio.subprocess import Process
 from concurrent.futures import ProcessPoolExecutor, ThreadPoolExecutor
+from concurrent.futures.process import BrokenProcessPool
 from contextlib import contextmanager
+from functools import partial, wraps
 from typing import Callable, Generator, Optional
 
+from psutil import Popen
+
 import rosys
 
 process_pool = ProcessPoolExecutor()
@@ -17,10 +23,12 @@ running_sh_processes: list[Process] = []
 log = logging.getLogger('rosys.run')
 
 
-async def io_bound(callback: Callable, *args: any):
+async def io_bound(callback: Callable, *args: any, **kwargs: any):
+    if rosys.is_stopping():
+        return
     loop = asyncio.get_running_loop()
     try:
-        return await loop.run_in_executor(thread_pool, callback, *args)
+        return await loop.run_in_executor(thread_pool, partial(callback, *args, **kwargs))
     except RuntimeError as e:
         if 'cannot schedule new futures after shutdown' not in str(e):
             raise
@@ -28,11 +36,23 @@ async def io_bound(callback: Callable, *args: any):
         pass
 
 
+def awaitable(func: Callable) -> Callable:
+    '''decorator to wrap a normal function into an asyncio coroutine'''
+    @wraps(func)
+    async def inner(*args, **kwargs):
+        return await io_bound(func, *args, **kwargs)
+    return inner
+
+
 async def cpu_bound(callback: Callable, *args: any):
+    if rosys.is_stopping():
+        return
     with cpu():
         try:
             loop = asyncio.get_running_loop()
             return await loop.run_in_executor(process_pool, callback, *args)
+        except BrokenProcessPool:
+            pass
         except RuntimeError as e:
             if 'cannot schedule new futures after shutdown' not in str(e):
                 raise
@@ -50,7 +70,7 @@ def cpu() -> Generator[None, None, None]:
         running_cpu_bound_processes.remove(id)
 
 
-async def sh(command: list[str] | str, timeout: Optional[float] = 1, shell: bool = False) -> str:
+async def sh(command: list[str] | str, timeout: Optional[float] = 1, shell: bool = False, working_dir: Optional[str] = None) -> str:
     '''executes a shell command
 
     Args:
@@ -70,27 +90,38 @@ async def sh(command: list[str] | str, timeout: Optional[float] = 1, shell: bool
                 cmd = f'timeout {timeout} {cmd}'
             else:
                 cmd = ['timeout', str(timeout)] + cmd
-        #log.info(f'running sh: "{cmd}"')
+        # log.info(f'running sh: "{cmd}"')
         proc = subprocess.Popen(
             cmd,
+            cwd=working_dir,
             stdout=asyncio.subprocess.PIPE,
             stderr=asyncio.subprocess.STDOUT,
             shell=shell,
+            start_new_session=True,
         )
         running_sh_processes.append(proc)
         stdout, *_ = proc.communicate()
-        proc.kill()
+        _kill(proc)
         running_sh_processes.remove(proc)
         return stdout.decode('utf-8')
+    if rosys.is_stopping():
+        return
     return await io_bound(popen)
 
 
+def _kill(proc: Popen) -> None:
+    try:
+        os.killpg(os.getpgid(proc.pid), signal.SIGTERM)
+        log.info(f'killed {proc.pid}')
+    except ProcessLookupError:
+        pass
+
+
 def tear_down() -> None:
     # stopping process as described in https://www.cloudcity.io/blog/2019/02/27/things-i-wish-they-told-me-about-multiprocessing-in-python/
     log.info('teardown thread_pool')
     thread_pool.shutdown(wait=False, cancel_futures=True)
-    [p.join(2) for p in running_sh_processes]
-    [p.terminate() for p in running_sh_processes if p.is_alive()]
+    [_kill(p) for p in running_sh_processes]
     running_sh_processes.clear()
     if not rosys.is_test:
         log.info('teardown process_pool')
